==> haskell-esqueleto-3.4.0.1-54-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-esqueleto.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 esqueleto
version:              3.4.0.1
visibility:           public
id:                   esqueleto-3.4.0.1-F7j9UNxrUbGG5mLAI6rZEc
key:                  esqueleto-3.4.0.1-F7j9UNxrUbGG5mLAI6rZEc
license:              BSD-3-Clause
copyright:            (c) 2012-2016 Felipe Almeida Lessa
maintainer:           cma@bitemyapp.com
author:               Felipe Lessa
homepage:             https://github.com/bitemyapp/esqueleto
synopsis:             Type-safe EDSL for SQL queries on persistent backends.
description:
    @esqueleto@ is a bare bones, type-safe EDSL for SQL queries that works with unmodified @persistent@ SQL backends.  Its language closely resembles SQL, so you don'\''t have to learn new concepts, just new syntax, and it'\''s fairly easy to predict the generated SQL and optimize it for your backend. Most kinds of errors committed when writing SQL are caught as compile-time errors---although it is possible to write type-checked @esqueleto@ queries that fail at runtime.

    @persistent@ is a library for type-safe data serialization.  It has many kinds of backends, such as SQL backends (@persistent-mysql@, @persistent-postgresql@, @persistent-sqlite@) and NoSQL backends (@persistent-mongoDB@). While @persistent@ is a nice library for storing and retrieving records, including with filters, it does not try to support some of the features that are specific to SQL backends.  In particular, @esqueleto@ is the recommended library for type-safe @JOIN@s on @persistent@ SQL backends.  (The alternative is using raw SQL, but that'\''s error prone and does not offer any composability.)

    Currently, @SELECT@s, @UPDATE@s, @INSERT@s and @DELETE@s are supported. Not all SQL features are available, but most of them can be easily added (especially functions), so please open an issue or send a pull request if you need anything that is not covered by @esqueleto@ on <https://github.com/bitemyapp/esqueleto>.

    The name of this library means \"skeleton\" in Portuguese and contains all three SQL letters in the correct order =).  It was inspired by Scala'\''s Squeryl but created from scratch.

category:             Database
abi:                  3cb8e01e01481d949be16a9a446604f6
exposed:              True
exposed-modules:
    Database.Esqueleto Database.Esqueleto.Experimental
    Database.Esqueleto.Internal.ExprParser
    Database.Esqueleto.Internal.Internal
    Database.Esqueleto.Internal.Language
    Database.Esqueleto.Internal.Sql Database.Esqueleto.MySQL
    Database.Esqueleto.PostgreSQL Database.Esqueleto.PostgreSQL.JSON
    Database.Esqueleto.SQLite

hidden-modules:
    Database.Esqueleto.Internal.PersistentImport
    Database.Esqueleto.PostgreSQL.JSON.Instances Paths_esqueleto

import-dirs:          /usr/lib/ghc-8.10.3/site-local/esqueleto-3.4.0.1
library-dirs:         /usr/lib/ghc-8.10.3/site-local/esqueleto-3.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/esqueleto-3.4.0.1
hs-libraries:         HSesqueleto-3.4.0.1-F7j9UNxrUbGG5mLAI6rZEc
depends:
    aeson-1.5.5.1-AwM5PjoCXg9Gz7zfwWBIzV
    attoparsec-0.13.2.4-3KIunrRLdh4G7KtfrdatRR base-4.14.1.0
    blaze-html-0.9.1.2-Fty6V0RKhoD8TdWgP8eRv0 bytestring-0.10.12.0
    conduit-1.3.4-JSLjoRVlhvXH9py6h408mx containers-0.6.2.1
    monad-logger-0.3.36-Jf3JeORE2jeFzXPQ2K8Ff3
    persistent-2.11.0.2-AgEJmPAZF4tLXGr2yStUOM
    resourcet-1.2.4.2-GKFFhTfsHG35or2nWqvxcD
    tagged-0.8.6.1-A3E8I7zg2qBFE9O5vQsg6C text-1.2.4.1 time-1.9.3
    transformers-0.5.6.2 unliftio-0.2.14-42AMgR1K0dx1sdpY7Gr27u
    unordered-containers-0.2.13.0-JMmUMTViutlBDpWEaCrbh4

haddock-interfaces:   /usr/share/doc/haskell-esqueleto/html/esqueleto.haddock
haddock-html:         /usr/share/doc/haskell-esqueleto/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-esqueleto-3.4.0.1-67-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-esqueleto.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 esqueleto
version:              3.4.0.1
visibility:           public
id:                   esqueleto-3.4.0.1-Apqr5nktW2DK8DHm3WEYz8
key:                  esqueleto-3.4.0.1-Apqr5nktW2DK8DHm3WEYz8
license:              BSD-3-Clause
copyright:            (c) 2012-2016 Felipe Almeida Lessa
maintainer:           cma@bitemyapp.com
author:               Felipe Lessa
homepage:             https://github.com/bitemyapp/esqueleto
synopsis:             Type-safe EDSL for SQL queries on persistent backends.
description:
    @esqueleto@ is a bare bones, type-safe EDSL for SQL queries that works with unmodified @persistent@ SQL backends.  Its language closely resembles SQL, so you don'\''t have to learn new concepts, just new syntax, and it'\''s fairly easy to predict the generated SQL and optimize it for your backend. Most kinds of errors committed when writing SQL are caught as compile-time errors---although it is possible to write type-checked @esqueleto@ queries that fail at runtime.

    @persistent@ is a library for type-safe data serialization.  It has many kinds of backends, such as SQL backends (@persistent-mysql@, @persistent-postgresql@, @persistent-sqlite@) and NoSQL backends (@persistent-mongoDB@). While @persistent@ is a nice library for storing and retrieving records, including with filters, it does not try to support some of the features that are specific to SQL backends.  In particular, @esqueleto@ is the recommended library for type-safe @JOIN@s on @persistent@ SQL backends.  (The alternative is using raw SQL, but that'\''s error prone and does not offer any composability.)

    Currently, @SELECT@s, @UPDATE@s, @INSERT@s and @DELETE@s are supported. Not all SQL features are available, but most of them can be easily added (especially functions), so please open an issue or send a pull request if you need anything that is not covered by @esqueleto@ on <https://github.com/bitemyapp/esqueleto>.

    The name of this library means \"skeleton\" in Portuguese and contains all three SQL letters in the correct order =).  It was inspired by Scala'\''s Squeryl but created from scratch.

category:             Database
abi:                  4ecfdd8967551e66fad850c42ed20199
exposed:              True
exposed-modules:
    Database.Esqueleto Database.Esqueleto.Experimental
    Database.Esqueleto.Internal.ExprParser
    Database.Esqueleto.Internal.Internal
    Database.Esqueleto.Internal.Language
    Database.Esqueleto.Internal.Sql Database.Esqueleto.MySQL
    Database.Esqueleto.PostgreSQL Database.Esqueleto.PostgreSQL.JSON
    Database.Esqueleto.SQLite

hidden-modules:
    Database.Esqueleto.Internal.PersistentImport
    Database.Esqueleto.PostgreSQL.JSON.Instances Paths_esqueleto

import-dirs:          /usr/lib/ghc-8.10.4/site-local/esqueleto-3.4.0.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/esqueleto-3.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/esqueleto-3.4.0.1
hs-libraries:         HSesqueleto-3.4.0.1-Apqr5nktW2DK8DHm3WEYz8
depends:
    aeson-1.5.5.1-6NWVvXrflAc8ojSfaztJWW
    attoparsec-0.13.2.5-HLmDNIwkLhHGlw3xuH7rpN base-4.14.1.0
    blaze-html-0.9.1.2-Hhla8wNlPJZ376l5s08ck bytestring-0.10.12.0
    conduit-1.3.4-Im314EPegaULFvbEcfi3YT containers-0.6.2.1
    monad-logger-0.3.36-D0e89RbrtXTAg89P39WNc3
    persistent-2.11.0.2-CCksokKkulX925mr6EWn95
    resourcet-1.2.4.2-2ekyREjGHPF2SHMD6OeBDa
    tagged-0.8.6.1-A3E8I7zg2qBFE9O5vQsg6C text-1.2.4.1 time-1.9.3
    transformers-0.5.6.2 unliftio-0.2.14-5es953KEYNxJN28MDqMdcb
    unordered-containers-0.2.13.0-48OepUjtvPcKuQlUwC19ed

haddock-interfaces:   /usr/share/doc/haskell-esqueleto/html/esqueleto.haddock
haddock-html:         /usr/share/doc/haskell-esqueleto/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
